# Copyright (C) 2024, UChicago Argonne, LLC
# Licensed under the 3-clause BSD license.  See accompanying LICENSE.txt file
# in the top-level directory.

from enum import Enum
from pandas import to_datetime as pddt
from Octeres.SL.location_to_mask_graph import XLocation_to_Mask_None
from Octeres.SL.abstract_location_to_mask import ABC_Location_to_Mask_Graph

_, MACHINE_NAME = __name__.rsplit("ltm_", 1)


class Obj_Type(Enum):
    ROOT = "root"
    NODE = "node"
    NODE_NAME = "node_name"
    NODE_NAME_SHORT = "node_name_short"


class Location_to_Mask(ABC_Location_to_Mask_Graph):
    machine_name = MACHINE_NAME
    bit_total = 24
    obj_types = [Obj_Type.ROOT.value, Obj_Type.NODE.value]
    names = [
        (
            (Obj_Type.NODE_NAME.value, (1, 25, 1), "fc{node_name}.salac"),
            (Obj_Type.NODE_NAME_SHORT.value, (0, 1, 1), "fc{node_name}"),
        ),
    ]

    def get_parents(self, machine_name: str, node_name: str) -> list:
        if machine_name == node_name:
            parents = []
        else:
            if node_name.endswith(f".{machine_name}"):
                parents = [machine_name]
            else:
                parents = [f"{node_name}.{machine_name}"]
        return parents

    def get_obj_type(self, machine_name: str, node_name: str) -> str:
        if machine_name == node_name:
            obj_type = Obj_Type.ROOT.value
        else:
            if node_name.endswith(f".{machine_name}"):
                obj_type = Obj_Type.NODE_NAME.value
            else:
                obj_type = Obj_Type.NODE_NAME_SHORT.value
        return obj_type


ltm_lst = [
    {
        "ts": pddt("1970-01-01"),
        "te": pddt("2015-06-01"),
        "ltm_class": XLocation_to_Mask_None,
        "name": MACHINE_NAME,
    },
    {
        "ts": pddt("2015-06-01"),
        "te": pddt("2038-01-01"),
        "ltm_class": Location_to_Mask,
        "pk": 27825,
        "name": MACHINE_NAME,
    },
]
